==> haskell-th-lift-instances-0.1.11-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift-instances
version: 0.1.11
id: th-lift-instances-0.1.11-26w65opR3jBHodA1egFP30
key: th-lift-instances-0.1.11-26w65opR3jBHodA1egFP30
license: BSD3
copyright: Copyright (C) 2013-2016 Benno Fünfstück
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
stability: experimental
homepage: http://github.com/bennofs/th-lift-instances/
synopsis: Lift instances for template-haskell for common data types.
description:
    Most data types in haskell platform do not have Lift instances. This package provides orphan instances
    for containers, text, bytestring and vector.
category: Template Haskell
author: Benno Fünfstück
exposed: True
exposed-modules:
    Instances.TH.Lift
abi: 6922aa6ff4e16ed0e2980db006da5216
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/th-lift-instances-0.1.11
library-dirs: /usr/lib/ghc-8.0.1/site-local/th-lift-instances-0.1.11
data-dir: /usr/share/i386-linux-ghc-8.0.1/th-lift-instances-0.1.11
hs-libraries: HSth-lift-instances-0.1.11-26w65opR3jBHodA1egFP30
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    th-lift-0.7.6-3YgW6AFnN6SEjgDav6Czfy
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock
haddock-html: /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-instances-0.1.11-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift-instances
version: 0.1.11
id: th-lift-instances-0.1.11-DLUWPVBm41gAHGhVdwx66v
key: th-lift-instances-0.1.11-DLUWPVBm41gAHGhVdwx66v
license: BSD3
copyright: Copyright (C) 2013-2016 Benno Fünfstück
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
stability: experimental
homepage: http://github.com/bennofs/th-lift-instances/
synopsis: Lift instances for template-haskell for common data types.
description:
    Most data types in haskell platform do not have Lift instances. This package provides orphan instances
    for containers, text, bytestring and vector.
category: Template Haskell
author: Benno Fünfstück
exposed: True
exposed-modules:
    Instances.TH.Lift
abi: b9d34fc7110019618625cd00bae65ef3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/th-lift-instances-0.1.11
library-dirs: /usr/lib/ghc-8.0.1/site-local/th-lift-instances-0.1.11
data-dir: /usr/share/i386-linux-ghc-8.0.1/th-lift-instances-0.1.11
hs-libraries: HSth-lift-instances-0.1.11-DLUWPVBm41gAHGhVdwx66v
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    th-lift-0.7.7-JuNRTOt9I9JCRNDoGbQTGn
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock
haddock-html: /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
